@@ -257,6 +257,25 @@ def parse_imbalance_prices(xml_text):
     return df
 
 
+def parse_imbalance_volumes(xml_text):
+    """
+    Parameters
+    ----------
+    xml_text : str
+
+    Returns
+    -------
+    pd.DataFrame
+    """
+    timeseries_blocks = _extract_timeseries(xml_text)
+    frames = (_parse_imbalance_volumes_timeseries(soup)
+              for soup in timeseries_blocks)
+    df = pd.concat(frames, axis=1)
+    df = df.stack().unstack()  # ad-hoc fix to prevent column splitting by NaNs
+    df.sort_index(inplace=True)
+    return df
+
+
 def parse_procured_balancing_capacity(xml_text, tz):
     """
     Parameters
@@ -441,6 +460,62 @@ def _parse_imbalance_prices_timeseries(soup) -> pd.DataFrame:
     return df
 
 
+def parse_imbalance_volumes_zip(zip_contents: bytes) -> pd.DataFrame:
+    """
+    Parameters
+    ----------
+    zip_contents : bytes
+
+    Returns
+    -------
+    pd.DataFrame
+    """
+    def gen_frames(archive):
+        with zipfile.ZipFile(BytesIO(archive), 'r') as arc:
+            for f in arc.infolist():
+                if f.filename.endswith('xml'):
+                    frame = parse_imbalance_volumes(xml_text=arc.read(f))
+                    yield frame
+
+    frames = gen_frames(zip_contents)
+    df = pd.concat(frames)
+    df.sort_index(inplace=True)
+    return df
+
+
+def _parse_imbalance_volumes_timeseries(soup) -> pd.DataFrame:
+    """
+    Parameters
+    ----------
+    soup : bs4.element.tag
+
+    Returns
+    -------
+    pd.DataFrame
+    """
+    flow_direction_factor = {
+        'A01': 1, # in
+        'A02': -1 # out
+    }[soup.find('flowdirection.direction').text]
+
+    df = pd.DataFrame(columns=['Imbalance Volume'])
+
+    for period in soup.find_all('period'):
+        start = pd.to_datetime(period.find('timeinterval').find('start').text)
+        end = pd.to_datetime(period.find('timeinterval').find('end').text)
+        resolution = _resolution_to_timedelta(period.find('resolution').text)
+        tx = pd.date_range(start=start, end=end, freq=resolution, inclusive='left')
+        points = period.find_all('point')
+
+        for dt, point in zip(tx, points):
+            df.loc[dt, 'Imbalance Volume'] = \
+                float(point.find('quantity').text) * flow_direction_factor
+
+    df.set_index(['Imbalance Volume'])
+
+    return df
+
+
 def _parse_netposition_timeseries(soup):
     """
     Parameters
@@ -697,6 +772,8 @@ _INV_BIDDING_ZONE_DICO = {area.code: area.name for area in Area}
 
 HEADERS_UNAVAIL_GEN = ['created_doc_time',
                        'docstatus',
+                       'mrid',
+                       'revision',
                        'businesstype',
                        'biddingzone_domain',
                        'qty_uom',
@@ -832,6 +909,8 @@ def _outage_parser(xml_file: bytes, headers, ts_func) -> pd.DataFrame:
     xml_text = xml_file.decode()
 
     soup = bs4.BeautifulSoup(xml_text, 'html.parser')
+    mrid = soup.find("mrid").text
+    revision_number = int(soup.find("revisionnumber").text)
     try:
         creation_date = pd.Timestamp(soup.createddatetime.text)
     except AttributeError:
@@ -844,7 +923,7 @@ def _outage_parser(xml_file: bytes, headers, ts_func) -> pd.DataFrame:
     d = list()
     series = _extract_timeseries(xml_text)
     for ts in series:
-        row = [creation_date, docstatus]
+        row = [creation_date, docstatus, mrid, revision_number]
         for t in ts_func(ts):
             d.append(row + t)
     df = pd.DataFrame.from_records(d, columns=headers)
